@@ -1,7 +1,7 @@
 set -e
 
 # extract new phrases
-/usr/local/opt/gettext/bin/xgettext --from-code=UTF-8 -o humanize.pot -k'_' -k'N_' -k'P_:1c,2' -l python src/humanize/*.py
+/usr/local/opt/gettext/bin/xgettext --from-code=UTF-8 -o humanize.pot -k'_' -k'N_' -k'P_:1c,2' -k'NS_:1,2' -l python src/humanize/*.py
 
 for d in src/humanize/locale/*/; do
     locale="$(basename $d)"
