@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """Number tests."""
 
 import pytest
@@ -72,6 +70,9 @@ def test_intword_powers():
     "test_args, expected",
     [
         (["100"], "100"),
+        (["1000"], "1.0 thousand"),
+        (["12400"], "12.4 thousand"),
+        (["12490"], "12.5 thousand"),
         (["1000000"], "1.0 million"),
         (["1200000"], "1.2 million"),
         (["1290000"], "1.3 million"),
@@ -88,7 +89,7 @@ def test_intword_powers():
         (["8100000000000000000000000000000000"], "8.1 decillion"),
         ([None], None),
         (["1230000", "%0.2f"], "1.23 million"),
-        ([10 ** 101], "1" + "0" * 101),
+        ([10**101], "1" + "0" * 101),
     ],
 )
 def test_intword(test_args, expected):
@@ -154,3 +155,20 @@ def test_fractional(test_input, expected):
 )
 def test_scientific(test_args, expected):
     assert humanize.scientific(*test_args) == expected
+
+
+@pytest.mark.parametrize(
+    "test_args, expected",
+    [
+        ([1], "1"),
+        ([None], None),
+        ([0.0001, "{:.0%}"], "0%"),
+        ([0.0001, "{:.0%}", 0.01], "<1%"),
+        ([0.9999, "{:.0%}", None, 0.99], ">99%"),
+        ([0.0001, "{:.0%}", 0.01, None, "under ", None], "under 1%"),
+        ([0.9999, "{:.0%}", None, 0.99, None, "above "], "above 99%"),
+        ([1, humanize.intword, 1e6, None, "under "], "under 1.0 million"),
+    ],
+)
+def test_clamp(test_args, expected):
+    assert humanize.clamp(*test_args) == expected
