@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """Tests for time humanizing."""
 
 import datetime as dt
@@ -62,10 +60,10 @@ def test_date_and_delta():
     results = [(now - td(seconds=x), td(seconds=x)) for x in int_tests]
     for t in (int_tests, date_tests, td_tests):
         for arg, result in zip(t, results):
-            date, d = time.date_and_delta(arg)
+            date, d = time._date_and_delta(arg)
             assertEqualDatetime(date, result[0])
             assertEqualTimedelta(d, result[1])
-    assert time.date_and_delta("NaN") == (None, "NaN")
+    assert time._date_and_delta("NaN") == (None, "NaN")
 
 
 # Tests for the public interface of humanize.time
@@ -120,7 +118,10 @@ def test_naturaldelta_nomonths(test_input, expected):
         (dt.timedelta(days=65), "2 months"),
         (dt.timedelta(days=9), "9 days"),
         (dt.timedelta(days=365), "a year"),
-        ("NaN", "NaN"),
+        (dt.timedelta(days=365 * 1_141), "1,141 years"),
+        ("NaN", "NaN"),  # Returns non-numbers unchanged.
+        # largest possible timedelta
+        (dt.timedelta(days=999_999_999), "2,739,726 years"),
     ],
 )
 def test_naturaldelta(test_input, expected):
@@ -334,37 +335,6 @@ def test_naturaldelta_minimum_unit_explicit(minimum_unit, seconds, expected):
     assert humanize.naturaldelta(delta, minimum_unit=minimum_unit) == expected
 
 
-@pytest.mark.parametrize(
-    "test_input, when, expected",
-    [
-        (NOW, NOW, "a moment"),
-        (NOW_UTC, NOW_UTC, "a moment"),
-    ],
-)
-def test_naturaldelta_when_explicit(test_input, when, expected):
-    # Act / Assert
-    assert humanize.naturaldelta(test_input, when=when) == expected
-
-
-@pytest.mark.parametrize(
-    "value, when",
-    [
-        (NOW_UTC, None),
-        (NOW_UTC, NOW),
-        (NOW_UTC_PLUS_01_00, None),
-        (NOW_UTC_PLUS_01_00, NOW),
-    ],
-)
-def test_naturaldelta_when_missing_tzinfo(value, when):
-    """Subtraction `when - value` is not defined by the `datetime` module when
-    either operand has not timezone-info (`tz=None`) and raises a TypeError.
-    """
-
-    # Act / Assert
-    with pytest.raises(TypeError):
-        humanize.naturaldelta(value, when=when)
-
-
 @pytest.mark.parametrize(
     "seconds, expected",
     [
@@ -448,6 +418,7 @@ def test_naturaltime_minimum_unit_explicit(minimum_unit, seconds, expected):
         (3600 * 24 * 2, "seconds", "2 days"),
         (3600 * 24 * 365, "seconds", "1 year"),
         (3600 * 24 * 365 * 2, "seconds", "2 years"),
+        (3600 * 24 * 365 * 1_963, "seconds", "1,963 years"),
     ],
 )
 def test_precisedelta_one_unit_enough(val, min_unit, expected):
